@@ -2,7 +2,7 @@
 /* This file is part of ngs_plumbing. */
 
 /* ngs_plumbing is free software: you can redistribute it and/or modify */
-/* it under the terms of the GNU General Public License as published by */
+/* it under the terms of the GNU Affero General Public License as published by */
 /* the Free Software Foundation, either version 3 of the License, or */
 /* (at your option) any later version. */
 
@@ -11,7 +11,7 @@
 /* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
 /* GNU General Public License for more details. */
 
-/* You should have received a copy of the GNU General Public License */
+/* You should have received a copy of the GNU Affero General Public License */
 /* along with ngs_plumbing.  If not, see <http://www.gnu.org/licenses/>. */
 
 /* Copyright 2012 Laurent Gautier */
@@ -477,9 +477,7 @@ static PyObject* slice_frombit2bytes(PyObject *self, PyObject *args)
 
   const Py_ssize_t ilow_p = ilow / NGSP_WORD_SIZE;
   const Py_ssize_t ihigh_p = (ihigh / NGSP_WORD_SIZE) + ((ihigh % 4 == 0) ? 0 : 1);
-  const int shiftlow = ilow % NGSP_WORD_SIZE;
-  const int shifthigh = NGSP_WORD_SIZE - shiftlow;
-
+  
   if (ihigh_p > (n_p+1)) {
     PyErr_Format(PyExc_IndexError,
 		 "Highest limit for the interval out of bound "
@@ -640,7 +638,7 @@ static struct PyModuleDef libdnamodule = {
    "_libdna",           /* name of module */
    module_doc,               /* module documentation, may be NULL */
    -1,                     /* size of per-interpreter state */
-   libdna_methods       /* method table */
+   libxsq_methods       /* method table */
  };
 #endif
 
