@@ -36,13 +36,13 @@ class FastqTestCase(unittest.TestCase):
     def test_read_fastq(self):
         data = self._data
         res = tuple(fastq.read_fastq(data))
-        self.assertEquals(3, len(res))
+        self.assertEqual(3, len(res))
         self.assertTrue(isinstance(res[0], fastq.Entry))
         self.assertTrue(isinstance(res[1], fastq.Entry))
         for i in range(3):
-            self.assertEquals(data[i*4], res[i].header)
-            self.assertEquals(data[(i*4)+1], res[i].sequence)
-            self.assertEquals(data[(i*4)+3], res[i].quality)
+            self.assertEqual(data[i*4], res[i].header)
+            self.assertEqual(data[(i*4)+1], res[i].sequence)
+            self.assertEqual(data[(i*4)+3], res[i].quality)
  
 
 def suite():
