@@ -19,13 +19,18 @@ import unittest
 import ngs_plumbing.ngsp_string as string
 import io
 
+# Compatibility with Python 3
+import sys
+if sys.version_info[0] > 2:
+    long = int
+
 class StringTestCase(unittest.TestCase):
     def test_randomstring(self):
-        rna = string.randomstring(long(100), 'AUGC')
+        rna = string.randomstring(long(100), b'AUGC')
         self.assertEqual(100, len(rna))
 
     def test_randomfragments(self):
-        rna = string.randomstring(long(100), 'AUGC')
+        rna = string.randomstring(long(100), b'AUGC')
         fragments = string.randomfragments(rna, 10, size = 5)
         self.assertEqual(len(fragments), 10)
         for f in fragments:
